@@ -1,7 +1,7 @@
 /*
  * libopenraw - cameraids.h
  *
- * Copyright (C) 2012-2022 Hubert Figuière
+ * Copyright (C) 2012-2023 Hubert Figuière
  *
  * This library is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -247,6 +247,8 @@ enum _OR_TYPEID_VENDOR_CANON {
     OR_TYPEID_CANON_EOS_R7 = 116,
     OR_TYPEID_CANON_EOS_R10 = 117,
     OR_TYPEID_CANON_EOS_R6MKII = 118,
+    OR_TYPEID_CANON_EOS_R8 = 119,
+    OR_TYPEID_CANON_EOS_R50 = 120,
     _OR_TYPEID_CANON_LAST
 };
 
@@ -778,6 +780,7 @@ enum _OR_TYPEID_VENDOR_PANASONIC {
     OR_TYPEID_PANASONIC_DC_G99 = 69,
     OR_TYPEID_PANASONIC_DC_G90 = OR_TYPEID_PANASONIC_DC_G99,
     OR_TYPEID_PANASONIC_DC_G91 = OR_TYPEID_PANASONIC_DC_G99,
+    OR_TYPEID_PANASONIC_DC_G95D = OR_TYPEID_PANASONIC_DC_G99,
     OR_TYPEID_PANASONIC_DC_S1H = 70,
     OR_TYPEID_PANASONIC_DC_G100 = 71,
     OR_TYPEID_PANASONIC_DC_G110 = OR_TYPEID_PANASONIC_DC_G100,
@@ -801,6 +804,7 @@ enum _OR_TYPEID_VENDOR_PANASONIC {
     OR_TYPEID_PANASONIC_TZ71 = OR_TYPEID_PANASONIC_ZS50,
     OR_TYPEID_PANASONIC_ZS70 = 83,
     OR_TYPEID_PANASONIC_TZ90 = OR_TYPEID_PANASONIC_ZS70,
+    OR_TYPEID_PANASONIC_DC_S5M2 = 84,
     _OR_TYPEID_PANASONIC_LAST
 };
 
